@@ -1,35 +1,39 @@
 package WWW::Google::CustomSearch::Item;
 
-use Moose;
-use namespace::clean;
+$WWW::Google::CustomSearch::Item::VERSION = '0.13';
 
+use 5.006;
 use Data::Dumper;
 
+use Moo;
+use namespace::clean;
+
 =head1 NAME
 
 WWW::Google::CustomSearch::Item - Placeholder for Google JSON/Atom Custom Search Item.
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =cut
 
-our $VERSION = '0.12';
-
-has 'kind'             => (is => 'ro', isa => 'Str');
-has 'link'             => (is => 'ro', isa => 'Str');
-has 'displayLink'      => (is => 'ro', isa => 'Str');
-has 'snippet'          => (is => 'ro', isa => 'Str');
-has 'htmlSnippet'      => (is => 'ro', isa => 'Str');
-has 'cacheId'          => (is => 'ro', isa => 'Str');
-has 'formattedUrl'     => (is => 'ro', isa => 'Str');
-has 'htmlFormattedUrl' => (is => 'ro', isa => 'Str');
-has 'title'            => (is => 'ro', isa => 'Str');
-has 'htmlTitle'        => (is => 'ro', isa => 'Str');
+has 'kind'             => (is => 'ro');
+has 'link'             => (is => 'ro');
+has 'displayLink'      => (is => 'ro');
+has 'snippet'          => (is => 'ro');
+has 'htmlSnippet'      => (is => 'ro');
+has 'cacheId'          => (is => 'ro');
+has 'formattedUrl'     => (is => 'ro');
+has 'htmlFormattedUrl' => (is => 'ro');
+has 'title'            => (is => 'ro');
+has 'htmlTitle'        => (is => 'ro');
 
 =head1 DESCRIPTION
 
+Provides  the  interface  to the individual search page result items based on the
+search criteria.
+
 =head1 METHODS
 
 =head2 kind()
@@ -43,7 +47,7 @@ Returns the 'kind' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item Kind: ", $item->kind, "\n" if defined $item->kind;
     }
 
@@ -58,7 +62,7 @@ Returns the 'link' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item Link: ", $item->link, "\n" if defined $item->link;
     }
 
@@ -73,7 +77,7 @@ Returns the 'displayLink' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item Display Link: ", $item->displayLink, "\n" if defined $item->displayLink;
     }
 
@@ -88,7 +92,7 @@ Returns the 'snippet' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item Snippet: ", $item->snippet, "\n" if defined $item->snippet;
     }
 
@@ -103,7 +107,7 @@ Returns the 'htmlSnippet' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item HTML Snippet: ", $item->htmlSnippet, "\n" if defined $item->htmlSnippet;
     }
 
@@ -118,7 +122,7 @@ Returns the 'cacheId' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item Cache Id: ", $item->cacheId, "\n" if defined $item->cacheId;
     }
 
@@ -133,7 +137,7 @@ Returns the 'formattedUrl' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item Formatted URL: ", $item->formattedUrl, "\n" if defined $item->formattedUrl;
     }
 
@@ -148,7 +152,7 @@ Returns the 'htmlFormattedUrl' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item HTML Formatted URL: ", $item->htmlFormattedUrl, "\n" if defined $item->htmlFormattedUrl;
     }
 
@@ -163,7 +167,7 @@ Returns the 'title' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item Title: ", $item->title, "\n" if defined $item->title;
     }
 
@@ -178,7 +182,7 @@ Returns the 'htmlTitle' attribute of the search.
     my $cx      = 'Search_Engine_Identifier';
     my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
     my $result  = $engine->search("Google");
-    foreach my $item ($result->items) {
+    foreach my $item (@{$result->items}) {
         print "Item HTML Title: ", $item->htmlTitle, "\n" if defined $item->htmlTitle;
     }
 
@@ -188,10 +192,10 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 BUGS
 
-Please report  any  bugs or feature requests to C<bug-www-google-customsearch at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Google-CustomSearch>.
-I will be notified and then you'll automatically be notified of progress on your bug as I make
-changes.
+Please  report  any  bugs or feature requests to C<bug-www-google-customsearch at
+rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Google-CustomSearch>.
+I will be notified, and then you'll automatically be notified of progress on your
+bug as I make changes.
 
 =head1 SUPPORT
 
@@ -203,7 +207,7 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * RT: CPAN's request tracker (report bugs here)
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Google-CustomSearch>
 
@@ -223,20 +227,42 @@ L<http://search.cpan.org/dist/WWW-Google-CustomSearch/>
 
 =head1 LICENSE AND COPYRIGHT
 
-This  program  is  free  software; you can redistribute it and/or modify it under the terms of
-either:  the  GNU  General Public License as published by the Free Software Foundation; or the
-Artistic License.
+Copyright 2014 Mohammad S Anwar.
 
-See http://dev.perl.org/licenses/ for more information.
+This  program  is  free software; you can redistribute it and/or modify it under
+the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
+license at:
 
-=head1 DISCLAIMER
+L<http://www.perlfoundation.org/artistic_license_2_0>
 
-This  program  is  distributed  in  the hope that it will be useful, but WITHOUT ANY WARRANTY;
-without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+Any  use,  modification, and distribution of the Standard or Modified Versions is
+governed by this Artistic License.By using, modifying or distributing the Package,
+you accept this license. Do not use, modify, or distribute the Package, if you do
+not accept this license.
+
+If your Modified Version has been derived from a Modified Version made by someone
+other than you,you are nevertheless required to ensure that your Modified Version
+ complies with the requirements of this license.
+
+This  license  does  not grant you the right to use any trademark,  service mark,
+tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge patent license
+to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
+Package with respect to any patent claims licensable by the Copyright Holder that
+are  necessarily  infringed  by  the  Package. If you institute patent litigation
+(including  a  cross-claim  or  counterclaim) against any party alleging that the
+Package constitutes direct or contributory patent infringement,then this Artistic
+License to you shall terminate on the date that such litigation is filed.
+
+Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
+CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
+WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
+NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
+REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
+INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
+OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
-no Moose; # Keywords are removed from the WWW::Google::CustomSearch::Item package
-
-1; # End of WWW::Google::CustomSearch::Item
\ No newline at end of file
+1; # End of WWW::Google::CustomSearch::Item
