@@ -1,11 +1,23 @@
 package WWW::Google::CustomSearch::Page;
 
-use Moose;
+$WWW::Google::CustomSearch::Page::VERSION = '0.13';
+
+use 5.006;
+use Data::Dumper;
+
+use Moo;
 use namespace::clean;
 
-use Data::Dumper;
-use Moose::Util::TypeConstraints;
-use WWW::Google::CustomSearch;
+has  'api_key'        => (is => 'ro', required => 1);
+has  'cx'             => (is => 'ro', required => 1);
+has  'safe'           => (is => 'ro', default => sub { return 'off' });
+has  'count'          => (is => 'ro');
+has  'searchTerms'    => (is => 'ro', required => 1);
+has  'inputEncoding'  => (is => 'ro', required => 1);
+has  'startIndex'     => (is => 'ro', default  => sub { return 1 });
+has  'title'          => (is => 'ro', required => 1);
+has  'totalResults'   => (is => 'ro', required => 1);
+has  'outputEncoding' => (is => 'ro', required => 1);
 
 =head1 NAME
 
@@ -13,23 +25,7 @@ WWW::Google::CustomSearch::Page - Placeholder for Google JSON/Atom Custom Search
 
 =head1 VERSION
 
-Version 0.12
-
-=cut
-
-our $VERSION = '0.12';
-
-type 'SafetyLevel'    => where { /\bhigh\b|\bmedium\b|\boff\b/i };
-has  'api_key'        => (is => 'ro', isa => 'Str', required => 1);
-has  'cx'             => (is => 'ro', isa => 'Str', required => 1);
-has  'safe'           => (is => 'ro', isa => 'SafetyLevel', default => 'off');
-has  'count'          => (is => 'ro', isa => 'Num');
-has  'searchTerms'    => (is => 'ro', isa => 'Str', required => 1);
-has  'inputEncoding'  => (is => 'ro', isa => 'Str', required => 1);
-has  'startIndex'     => (is => 'ro', isa => 'Num', default  => 1);
-has  'title'          => (is => 'ro', isa => 'Str', required => 1);
-has  'totalResults'   => (is => 'ro', isa => 'Num', required => 1);
-has  'outputEncoding' => (is => 'ro', isa => 'Str', required => 1);
+Version 0.13
 
 =head1 DESCRIPTION
 
@@ -167,10 +163,9 @@ object.
 =cut
 
 sub fetch {
-    my $self   = shift;
-    my $engine = WWW::Google::CustomSearch->new({ api_key => $self->api_key,
-                                                  cx      => $self->cx,
-                                                  start   => $self->startIndex });
+    my ($self) = @_;
+
+    my $engine = WWW::Google::CustomSearch->new({ api_key => $self->api_key, cx => $self->cx, start => $self->startIndex });
     return $engine->search($self->searchTerms);
 }
 
@@ -180,10 +175,10 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 BUGS
 
-Please report  any  bugs or feature requests to C<bug-www-google-customsearch at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Google-CustomSearch>.
-I will be notified and then you'll automatically be notified of progress on your bug as I make
-changes.
+Please  report any bugs or feature requests  to  C<bug-www-google-customsearch at
+rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WWW-Google-CustomSearch>.
+I will be notified, and then you'll automatically be notified of progress on your
+bug as I make changes.
 
 =head1 SUPPORT
 
@@ -195,7 +190,7 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * RT: CPAN's request tracker (report bugs here)
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WWW-Google-CustomSearch>
 
@@ -215,20 +210,42 @@ L<http://search.cpan.org/dist/WWW-Google-CustomSearch/>
 
 =head1 LICENSE AND COPYRIGHT
 
-This  program  is  free  software; you can redistribute it and/or modify it under the terms of
-either:  the  GNU  General Public License as published by the Free Software Foundation; or the
-Artistic License.
+Copyright 2014 Mohammad S Anwar.
 
-See http://dev.perl.org/licenses/ for more information.
+This  program  is  free software; you can redistribute it and/or modify it under
+the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
+license at:
 
-=head1 DISCLAIMER
+L<http://www.perlfoundation.org/artistic_license_2_0>
 
-This  program  is  distributed  in  the hope that it will be useful, but WITHOUT ANY WARRANTY;
-without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+Any  use,  modification, and distribution of the Standard or Modified Versions is
+governed by this Artistic License.By using, modifying or distributing the Package,
+you accept this license. Do not use, modify, or distribute the Package, if you do
+not accept this license.
+
+If your Modified Version has been derived from a Modified Version made by someone
+other than you,you are nevertheless required to ensure that your Modified Version
+ complies with the requirements of this license.
+
+This  license  does  not grant you the right to use any trademark,  service mark,
+tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge patent license
+to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
+Package with respect to any patent claims licensable by the Copyright Holder that
+are  necessarily  infringed  by  the  Package. If you institute patent litigation
+(including  a  cross-claim  or  counterclaim) against any party alleging that the
+Package constitutes direct or contributory patent infringement,then this Artistic
+License to you shall terminate on the date that such litigation is filed.
+
+Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
+CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
+WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
+NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
+REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
+INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
+OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-__PACKAGE__->meta->make_immutable;
-no Moose; # Keywords are removed from the WWW::Google::CustomSearch::Page package
-
-1; # End of WWW::Google::CustomSearch::Page
\ No newline at end of file
+1; # End of WWW::Google::CustomSearch::Page
